@@ -1,9 +1,9 @@
 # generic use functions
-from .init import init,init_without_connect
+from .init import init
 from .handling import add_handler
 from .parse import parsemsg
-from .network import connect,close,handle,addmessage
-from .logging import die
+from .network import setserver,connect,close,handle,addmessage,ignore,hasmessage,on_message,disconnect,subscribe,publish
+from .logging import die,quiet,verbose,setstdout,setfilelog
 from .watchdog import check,start
 #internal functions
 from .logging import _init_log_settings
@@ -23,14 +23,18 @@ cmd_switch={}
 import selectors
 network_info={}
 network_info["host"]='localhost'
-network_info["port"]=9818
+#network_info["port"]=9818
+network_info["port"]=1883
 network_info["selector"]=selectors.DefaultSelector()
 network_info["isconnected"]=False
-network_info["name"]='Unknown'
+network_info["timeconnected"]=0
+network_info["name"]="Unknown"
 network_info["outgoing"]=[]
 network_info["last_ping"]=time.time()
 
-
+add_handler("_pong",ignore)
+add_handler("_quiet",quiet)
+add_handler("_verbose",verbose)
 
 ###
 # logger init code
