@@ -11,7 +11,10 @@ import traceback
 import time
 import libABCD
 
+# note: ch and fh are global variables for this module
+
 def _init_log_settings(logger):
+  global ch,fh
   logger.setLevel(logging.DEBUG)
   # log directory
   #logdir = os.path.join(os.getenv("HOME"), "Developer/log")
@@ -29,10 +32,31 @@ def _init_log_settings(logger):
   fh.setFormatter(formatter)
   ch.setFormatter(formatter)
   # add the handlers to the logger
-  logger.addHandler(fh)
-  logger.addHandler(ch)
+  logger.addHandler(fh)  # handler[0] is file dump
+  logger.addHandler(ch)  # handler[1] is stdout
 
 def die():
     exc_type, exc_value, exc_tb = sys.exc_info()
     libABCD.logger.critical("Shutting down: {}".format(traceback.format_exception(exc_type, exc_value, exc_tb)))
-    sys.exit(1)
+    os._exit(1)
+
+def quiet(data,conn):
+    try:
+        if libABCD.network_info["name"] == data["to"]:
+            ch.setLevel(logging.INFO)
+    except Exception as e:
+        print(e)
+        pass
+
+def verbose(data,conn):
+    try:
+        if libABCD.network_info["name"] == data["to"]:
+            ch.setLevel(logging.DEBUG)
+    except Exception as e:
+        pass
+
+def setfilelog(level=logging.INFO):
+    fh.setLevel(level)
+
+def setstdout(level=logging.DEBUG):
+    ch.setLevel(level)
